// SPDX-License-Identifier: GPL-3.0-or-later
// Copyright 2019 Juan Palacios <jpalaciosdev@gmail.com>

#pragma once

#include <string_view>

namespace AMD::GPUFreq {

static constexpr std::string_view ItemID{"AMD_GPU_FREQ"};

} // namespace AMD::GPUFreq
